@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdadd_cart.cpp,v 1.4 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdadd_cart.cpp,v 1.5 2007-10-04 20:53:28 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,8 +33,7 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
-
+#include <rddb.h>
 #include <rdpasswd.h>
 #include <rdgroup.h>
 #include <rdtextvalidator.h>
@@ -46,7 +45,7 @@ RDAddCart::RDAddCart(QString *group,RDCart::Type *type,QString *title,
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   cart_group=group;
   cart_type=type;
   cart_title=title;
@@ -86,7 +85,7 @@ RDAddCart::RDAddCart(QString *group,RDCart::Type *type,QString *title,
   sql=QString().sprintf("select GROUP_NAME from USER_PERMS \
                          where USER_NAME=\"%s\" order by GROUP_NAME",
 			(const char *)username);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     cart_group_box->insertItem(q->value(0).toString());
     if(q->value(0).toString()==*cart_group) {
@@ -135,7 +134,7 @@ RDAddCart::RDAddCart(QString *group,RDCart::Type *type,QString *title,
       QString().sprintf("select DEFAULT_CART_TYPE from GROUPS\
                          where NAME=\"%s\"",
 			(const char *)*cart_group);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->first()) {
       cart_type_box->setCurrentItem(q->value(0).toUInt()-1);
     }
@@ -214,7 +213,7 @@ void RDAddCart::groupActivatedData(const QString &groupname)
 
 void RDAddCart::okData()
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   unsigned num;
   RDGroup *group=new RDGroup(cart_group_box->currentText());
@@ -238,7 +237,7 @@ void RDAddCart::okData()
     }
   }
   sql=QString().sprintf("select NUMBER from CART where NUMBER=%u",num);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     QMessageBox::information(this,tr("Cart Exists"),
 			     tr("This cart already exists."),
