@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdaudio_exists.cpp,v 1.5 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdaudio_exists.cpp,v 1.6 2007-09-22 20:44:14 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,15 +23,13 @@
 #include <qstring.h>
 #include <qfile.h>
 #include <rd.h>
+#include <rdcut.h>
 #include <rdaudio_exists.h>
 
-
 bool RDAudioExists(QString cutname)
 {
   QFile file;
-
-  QString pathname=QString(RD_AUDIO_ROOT)+QString("/")+cutname+
-    QString(".")+QString(RD_AUDIO_EXTENSION);
+  QString pathname = RDCut::pathName(cutname); 
   file.setName(pathname);
   return file.exists();
 }
