@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcreate_log.cpp,v 1.31 2007/10/04 20:53:28 dmills Exp $
+//      $Id: rdcreate_log.cpp,v 1.34 2008-08-04 14:00:59 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,6 +21,7 @@
 //
 #include <rddb.h>
 #include <rdcreate_log.h>
+#include <rdescape_string.h>
 #include <rd.h>
 
 
@@ -77,7 +78,8 @@ EXT_ANNC_TYPE char(8),\
 INDEX COUNT_IDX (COUNT),\
 INDEX CART_NUMBER_IDX (CART_NUMBER),\
 INDEX LABEL_IDX (LABEL))",
-			   (const char *)name.replace(" ","_"),
+			   (const char *)
+			   RDEscapeStringSQLColumn(name.replace(" ","_")),
 			   RD_FADE_DEPTH,RD_FADE_DEPTH,RD_FADE_DEPTH);
 }
 
@@ -90,7 +92,8 @@ QString RDCreateClockTableSql(QString name)
                           START_TIME time not null,\
                           LENGTH int not null,\
                           INDEX EVENT_NAME_IDX (EVENT_NAME))",
-			   (const char *)name.replace(" ","_"));
+			   (const char *)
+			   RDEscapeStringSQLColumn(name.replace(" ","_")));
 }
 
 
@@ -126,7 +129,23 @@ QString RDCreateReconciliationTableSql(QString name)
                             EXT_EVENT_ID char(8),\
                             EXT_ANNC_TYPE char(8),\
                             index EVENT_DATETIME_IDX(EVENT_DATETIME))",
-			   (const char *)name.replace(" ","_"));
+			   (const char *)
+				RDEscapeStringSQLColumn(name.replace(" ","_")));
   // printf("SQL: %s\n",(const char *)sql);
   return sql;
 }
+
+
+QString RDCreateStackTableSql(QString name)
+{
+  QString sql;
+  sql=QString().sprintf("create table if not exists `%s_STACK` (\
+                         SCHED_STACK_ID int unsigned not null primary key,\
+                         CART int unsigned not null,\
+                         ARTIST varchar(255),\
+                         SCHED_CODES varchar(255),\
+                         SCHEDULED_AT datetime default '1000-01-01 00:00:00')",
+			(const char *)
+			RDEscapeStringSQLColumn(name.replace(" ","_")));
+  return sql;
+}
