@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsimpleplayer.cpp,v 1.4 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdsimpleplayer.cpp,v 1.11 2008-07-18 20:06:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,7 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <rddb.h>
 #include <rdsimpleplayer.h>
 
 
@@ -35,7 +36,6 @@ RDSimplePlayer::RDSimplePlayer(RDCae *cae,RDRipc *ripc,int card,int port,
   play_start_cart=start_cart;
   play_end_cart=end_cart;
   play_stream=-1;
-  play_handle=-1;
   play_cart=0;
   play_is_playing=false;
 
@@ -44,7 +44,6 @@ RDSimplePlayer::RDSimplePlayer(RDCae *cae,RDRipc *ripc,int card,int port,
   //
   connect(play_cae,SIGNAL(playing(int)),this,SLOT(playingData(int)));
   connect(play_cae,SIGNAL(playStopped(int)),this,SLOT(playStoppedData(int)));
-  connect(play_cae,SIGNAL(playUnloaded(int)),this,SLOT(playUnloadedData(int)));
 
   //
   // Event Player
@@ -56,6 +55,7 @@ RDSimplePlayer::RDSimplePlayer(RDCae *cae,RDRipc *ripc,int card,int port,
   //
   play_start_button=
     new RDTransportButton(RDTransportButton::Play,parent,"play_start_button");
+  play_start_button->setEnabled((play_card>=0)&&(play_port>=0));
   connect(play_start_button,SIGNAL(clicked()),this,SLOT(play()));
 
   //
@@ -64,6 +64,7 @@ RDSimplePlayer::RDSimplePlayer(RDCae *cae,RDRipc *ripc,int card,int port,
   play_stop_button=
     new RDTransportButton(RDTransportButton::Stop,parent,"play_stop_button");
   play_stop_button->on();
+  play_stop_button->setEnabled((play_card>=0)&&(play_port>=0));
   connect(play_stop_button,SIGNAL(clicked()),this,SLOT(stop()));
 
   hide();
@@ -72,6 +73,7 @@ RDSimplePlayer::RDSimplePlayer(RDCae *cae,RDRipc *ripc,int card,int port,
 
 RDSimplePlayer::~RDSimplePlayer()
 {
+  stop();
 }
 
 
@@ -95,30 +97,39 @@ RDTransportButton *RDSimplePlayer::stopButton() const
 
 void RDSimplePlayer::play()
 {
+  int handle=0;
   int play_cut_gain=0;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
-  if(play_is_playing||(play_cart==0)) {
+  if(play_cart==0) {
     return;
   }
-  sql=QString().sprintf("select CUT_NAME,START_POINT,END_POINT,PLAY_GAIN from CUTS \
-                         where (CART_NUMBER=%u)&&(LENGTH>0)",
+  if(play_is_playing) {
+    stop();
+  }
+  sql=QString().sprintf("select CUT_NAME,START_POINT,END_POINT,PLAY_GAIN\
+                         from CUTS where (CART_NUMBER=%u)&&(LENGTH>0)",
 			play_cart);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     play_cae->
-      loadPlay(play_card,q->value(0).toString(),&play_stream,&play_handle);
+      loadPlay(play_card,q->value(0).toString(),&play_stream,&handle);
     play_cut_gain=q->value(3).toInt(); 
     if(play_stream<0) {
       delete q;
       return;
     }
+    play_handles.push(handle);
+    for(int i=0;i<RD_MAX_PORTS;i++) {
+      play_cae->setOutputVolume(play_card,play_stream,i,RD_MUTE_DEPTH);
+    }
     play_cae->
       setOutputVolume(play_card,play_stream,play_port,0+play_cut_gain);
-    play_cae->positionPlay(play_handle,q->value(1).toUInt());
-    play_cae->play(play_handle,q->value(2).toUInt()-q->value(1).toUInt(),
-		   1000,false);
+    play_cae->positionPlay(play_handles.back(),q->value(1).toUInt());
+    play_cae->
+      play(play_handles.back(),q->value(2).toUInt()-q->value(1).toUInt(),
+		   RD_TIMESCALE_DIVISOR,false);
     play_cae->
       setPlayPortActive(play_card,play_port,play_stream);
   }
@@ -131,13 +142,16 @@ void RDSimplePlayer::stop()
   if(!play_is_playing) {
     return;
   }
-  play_cae->stopPlay(play_handle);
+  play_cae->stopPlay(play_handles.back());
 }
 
 
 void RDSimplePlayer::playingData(int handle)
 {
-  if(handle!=play_handle) {
+  if(play_handles.empty()) {
+    return;
+  }
+  if(handle!=play_handles.back()) {
     return;
   }
   play_event_player->exec(play_start_cart);
@@ -149,21 +163,16 @@ void RDSimplePlayer::playingData(int handle)
 
 void RDSimplePlayer::playStoppedData(int handle)
 {
-  if(handle!=play_handle) {
+  if(play_handles.empty()) {
     return;
   }
-  play_cae->unloadPlay(play_handle);
-}
-
-
-void RDSimplePlayer::playUnloadedData(int handle)
-{
-  if(handle!=play_handle) {
+  if(handle!=play_handles.front()) {
     return;
   }
+  play_cae->unloadPlay(play_handles.front());
   play_event_player->exec(play_end_cart);
   play_start_button->off();
   play_stop_button->on();
-  play_handle=-1;
+  play_handles.pop();
   play_is_playing=false;
 }
