@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdwavefile.cpp,v 1.1 2007/09/14 14:06:24 fredg Exp $
+//    $Id: rdwavefile.cpp,v 1.13 2008-10-16 19:28:38 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -29,6 +29,7 @@
 #include <syslog.h>
 #include <math.h>
 #include <fcntl.h>
+#include <arpa/inet.h>
 
 #include <id3/tag.h>
 #include <id3/misc_support.h>
@@ -38,6 +39,7 @@
 #include <qstring.h>
 #include <qdatetime.h>
 
+#include <rd.h>
 #include <rdwavefile.h>
 #include <rdconf.h>
 
@@ -160,6 +162,7 @@ RDWaveFile::RDWaveFile(QString file_name)
   serial_number=-1;
   atx_offset=0;
   scot_chunk=false;
+  av10_chunk=false;
 }
 
 
@@ -203,17 +206,20 @@ bool RDWaveFile::openWave(RDWaveData *data)
   }
   switch(GetType(wave_file.handle())) {
       case RDWaveFile::Wave:
-	if(!GetFmt(wave_file.handle())) {
-	  return false;
+	if(GetFmt(wave_file.handle())) {
+	  wave_type=RDWaveFile::Wave;
 	}
-	if(!GetChunk(wave_file.handle(),"data",&data_length,NULL,0)) { // Set fileptr to start
-	  return false;                                      // of data block. 
+	else {
+	  wave_type=RDWaveFile::Ambos;
+	  format_tag=WAVE_FORMAT_MPEG;
+	}
+	if(!GetChunk(wave_file.handle(),"data",&data_length,NULL,0)) { // Set fileptr to start of data block
+	  return false;
 	}
 	data_chunk=true;
 	data_start=lseek(wave_file.handle(),0,SEEK_CUR);
-	
 	if((!GetFact(wave_file.handle()))||(sample_length==0)) {
-	  if(format_tag!=WAVE_FORMAT_PCM) {
+	  if((format_tag!=WAVE_FORMAT_PCM)&&format_chunk) {
 #ifdef MPEG_FACT_FUDGE
 	    // Guesstimate the overall sample size
 	    time_length=data_length/avg_bytes_per_sec;
@@ -227,16 +233,37 @@ bool RDWaveFile::openWave(RDWaveData *data)
 #endif
 	  }
 	  else {
-	    ext_time_length=(unsigned)(1000.0*(double)data_length/
-				       (double)(block_align*samples_per_sec));
-	    time_length=ext_time_length/1000;
-	    sample_length=data_length/block_align;
+	    if(format_chunk) {
+	      ext_time_length=(unsigned)(1000.0*(double)data_length/
+					 (double)(block_align*samples_per_sec));
+	      time_length=ext_time_length/1000;
+	      sample_length=data_length/block_align;
+	    }
+	    else {
+	      if(!GetMpegHeader(wave_file.handle(),data_start)) {
+		wave_file.close();
+		return false;
+	      }
+	      data_length=wave_file.size()-data_start;
+	      sample_length=1152*(data_length/mpeg_frame_size);
+	      ext_time_length=(unsigned)(1000.0*(double)sample_length/
+					 (double)samples_per_sec);
+	      time_length=ext_time_length/1000;
+	      lseek(wave_file.handle(),data_start,SEEK_SET);
+	      format_chunk=true;
+	    }
 	  }
 	}
 	else {
-	  time_length=sample_length/samples_per_sec;
-	  ext_time_length=(unsigned)(1000.0*(double)sample_length/
-				     (double)samples_per_sec);
+	  if(format_chunk) {
+	    time_length=sample_length/samples_per_sec;
+	    ext_time_length=(unsigned)(1000.0*(double)sample_length/
+				       (double)samples_per_sec);
+	  }
+	  else {
+	    time_length=0;
+	    ext_time_length=0;
+	  }
 	}
 	GetCart(wave_file.handle());
 	GetBext(wave_file.handle());
@@ -244,7 +271,7 @@ bool RDWaveFile::openWave(RDWaveData *data)
 	GetLevl(wave_file.handle());
 	GetList(wave_file.handle());
 	GetScot(wave_file.handle());
-	wave_type=RDWaveFile::Wave;
+	GetAv10(wave_file.handle());
 	break;
 
       case RDWaveFile::Mpeg:
@@ -290,6 +317,7 @@ bool RDWaveFile::openWave(RDWaveData *data)
 	data_chunk=true;
 	format_chunk=true;
 	wave_type=RDWaveFile::Ogg;
+	ValidateMetadata();
 	return true;
 #else
 	return false;
@@ -356,6 +384,7 @@ bool RDWaveFile::openWave(RDWaveData *data)
 	break;
   }
   lseek(wave_file.handle(),data_start,SEEK_SET);
+  ValidateMetadata();
 
   return true;
 }
@@ -520,7 +549,13 @@ void RDWaveFile::closeWave(int samples)
 	    size_buf[3]=(lsize>>24)&0xff;
 	    write(wave_file.handle(),size_buf,4);
 	    write(wave_file.handle(),levl_chunk_data,LEVL_CHUNK_SIZE-4);
-	    write(wave_file.handle(),&(energy_data[0]),2*energy_data.size());
+	    // Fixup the endianness
+	    unsigned char * sbuf = new unsigned char [2 * energy_data.size()];
+	    for (unsigned int i=0; i < energy_data.size(); i++){
+	      WriteSword (sbuf,2*i,(unsigned short) energy_data[i]);
+	    }
+	    write(wave_file.handle(),sbuf,2*energy_data.size());
+	    delete [] sbuf;
 	    ftruncate(wave_file.handle(),lseek(wave_file.handle(),0,SEEK_CUR));
 	  }
 
@@ -737,6 +772,7 @@ void RDWaveFile::closeWave(int samples)
   encode_quality=5.0f;
   serial_number=-1;
   atx_offset=0;
+  av10_chunk=false;
 }
 
 
@@ -818,6 +854,7 @@ int RDWaveFile::readWave(void *buf,int count)
   int stream;
   int n;
   unsigned int pos;
+  int c = 0;
 
   switch(wave_type) {
       case RDWaveFile::Ogg:
@@ -838,12 +875,20 @@ int RDWaveFile::readWave(void *buf,int count)
         if (((pos+count)>(data_start+data_length))&&(data_length>0)) {
           count=count - ( (pos+count) - (data_start+data_length) );
         }
-	return read(wave_file.handle(),buf,count);
-
+	c = read(wave_file.handle(),buf,count);
+	break;
       default:
-	return read(wave_file.handle(),buf,count);
+	c = read(wave_file.handle(),buf,count);
   }
-  return 0;
+  if ( c <0 ) return 0; // read error
+  // Fixup the buffer for big endian hosts (Wav is defined as LE).
+  if (htonl (1l) == 1){ // Big endian host
+    for (unsigned int i = 0; i < c/2; i++){
+      ((short*)buf)[i] = ReadSword((unsigned char *)buf,2*i);
+    }
+  }
+
+  return c;
 }
 
 
@@ -907,6 +952,13 @@ int RDWaveFile::writeWave(void *buf,int count)
 	}
 	lseek(wave_file.handle(),0,SEEK_END);
 	data_length+=count;
+	// Fixup the buffer for big endian hosts (Wav is defined as LE).
+	if (htonl (1l) == 1l){ // Big endian host
+	  for (unsigned int i = 0; i < count/2; i++){
+	    unsigned short s = ((unsigned short*)buf)[i];
+	    WriteSword((unsigned char *)buf,2*i,s);
+	  }
+	}
 	return write(wave_file.handle(),buf,count);
 
       case WAVE_FORMAT_MPEG:
@@ -1899,6 +1951,7 @@ bool RDWaveFile::IsWav(int fd)
   else {
     return false;
   }
+
   return true;
 }
 
@@ -2011,7 +2064,7 @@ bool RDWaveFile::IsFlac(int fd)
 {
   char buffer[5];
 
-  ID3_Tag id3_tag(wave_file.name());
+  ID3_Tag id3_tag(QCString().sprintf("%s",(const char *)wave_file.name().utf8()));
   lseek(fd,id3_tag.GetPrependedBytes(),SEEK_SET);
   if(read(fd,buffer,4)!=4) {
     return false;
@@ -2095,6 +2148,7 @@ bool RDWaveFile::GetFmt(int fd)
    * Load the chunk
    */
   if(!GetChunk(fd,"fmt ",&chunk_size,fmt_chunk_data,FMT_CHUNK_SIZE)) {
+    format_chunk=false;
     return false;
   }
   format_chunk=true;
@@ -2200,18 +2254,24 @@ bool RDWaveFile::GetCart(int fd)
       j++;
     }
   }
-  cart_url=cutString((char *)cart_chunk_data,1020,64);
+  if(wave_type==RDWaveFile::Wave) {
+    cart_url=cutString((char *)cart_chunk_data,1024,1024);
 
-  //
-  // Get the Tag Text
-  //
-  if(chunk_size>2048) {
-    tag_buffer=(char *)malloc(chunk_size-2048+1);
-    read(wave_file.handle(),tag_buffer,chunk_size-2048);
-    tag_buffer[chunk_size-2048]=0;
-    cart_tag_text=tag_buffer;
-    free(tag_buffer);
-    tag_buffer=NULL;
+    //
+    // Get the Tag Text
+    //
+    if(chunk_size>2048) {
+      tag_buffer=(char *)malloc(chunk_size-2048+1);
+      read(wave_file.handle(),tag_buffer,chunk_size-2048);
+      tag_buffer[chunk_size-2048]=0;
+      cart_tag_text=tag_buffer;
+      free(tag_buffer);
+      tag_buffer=NULL;
+    }
+  }
+  else {
+    cart_url="";
+    cart_tag_text="";
   }
 
   if(wave_data!=NULL) {
@@ -2232,11 +2292,27 @@ bool RDWaveFile::GetCart(int fd)
     wave_data->setTagText(cart_tag_text);
     for(int i=0;i<MAX_TIMERS;i++) {
       if(cart_timer_label[i]=="SEGs") {
-	wave_data->setSegueLength((int)(1000.0*((double)cart_timer_sample[i])/
+	wave_data->setSegueStartPos((int)(1000.0*((double)cart_timer_sample[i])/
+					  ((double)getSamplesPerSec())));
+      }
+      if(cart_timer_label[i]=="SEGe") {
+	wave_data->setSegueEndPos((int)(1000.0*((double)cart_timer_sample[i])/
 					((double)getSamplesPerSec())));
       }
-      if(cart_timer_label[i].left(3)=="INT") {
-	wave_data->setIntroLength((int)(1000.0*((double)cart_timer_sample[i])/
+      if(cart_timer_label[i]=="INTs") {
+	wave_data->setIntroStartPos((int)(1000.0*((double)cart_timer_sample[i])/
+					  ((double)getSamplesPerSec())));
+      }
+      if(cart_timer_label[i]=="INTe") {
+	wave_data->setIntroEndPos((int)(1000.0*((double)cart_timer_sample[i])/
+					((double)getSamplesPerSec())));
+      }
+      if(cart_timer_label[i]=="AUDs") {
+	wave_data->setStartPos((int)(1000.0*((double)cart_timer_sample[i])/
+					  ((double)getSamplesPerSec())));
+      }
+      if(cart_timer_label[i]=="AUDe") {
+	wave_data->setEndPos((int)(1000.0*((double)cart_timer_sample[i])/
 					((double)getSamplesPerSec())));
       }
     }
@@ -2443,7 +2519,8 @@ bool RDWaveFile::GetScot(int fd)
     wave_data->setArtist(scot_artist.stripWhiteSpace());
     wave_data->setUserDefined(scot_etc.stripWhiteSpace());
     wave_data->setReleaseYear(scot_year);
-    wave_data->setIntroLength(scot_intro_length);
+    wave_data->setIntroStartPos(0);
+    wave_data->setIntroEndPos(scot_intro_length);
     if(scot_start_date.isValid()) {
       wave_data->setStartDate(scot_start_date);
     }
@@ -2461,6 +2538,146 @@ bool RDWaveFile::GetScot(int fd)
 }
 
 
+bool RDWaveFile::GetAv10(int fd)
+{
+  //
+  // The 'av10' chunk is used by BE AudioVault systems for metadata storage
+  //
+  unsigned chunk_size;
+  char temp[512];
+  unsigned ptr=1;
+  QString str;
+  int n;
+  int pos;
+  int offset;
+  bool ok=false;
+  int istate=0;
+  QString label;
+  QString arg;
+  QString userdef;
+
+  /*
+   * Load the chunk
+   */
+  if(!GetChunk(fd,"av10",&chunk_size,av10_chunk_data,AV10_CHUNK_SIZE)) {
+    return false;
+  }
+  av10_chunk=true;
+
+  //
+  // Walk through the fields
+  //
+  for(int i=2;i<chunk_size;i++) {
+    switch(istate) {
+      case 0:  // Label
+	if(av10_chunk_data[i]==0) {
+	  i++;
+	  istate=1;
+	}
+	else {
+	  label+=av10_chunk_data[i];
+	}
+	break;
+
+      case 1:  // Argument
+	if(av10_chunk_data[i]==0) {  // Found a label/value pair, see if we can
+                                     // use it
+	  if(label=="1") {  // Start/end markers
+	    if((n=arg.find(","))>0) {
+	      pos=arg.left(n).toInt(&ok);
+	      if(ok) {
+		offset=arg.right(arg.length()-n-1).toInt(&ok);
+		if(ok) {
+		  if(wave_data!=NULL) {
+		    wave_data->setStartPos(pos);
+		    wave_data->setEndPos(pos+offset);
+		    wave_data->setMetadataFound(true);
+		  }
+		}
+	      }
+	    }
+	  }
+	  if(label=="2") {  // Segue markers
+	    if((n=arg.find(","))>0) {
+	      pos=arg.left(n).toInt(&ok);
+	      if(ok) {
+		offset=arg.right(arg.length()-n-1).toInt(&ok);
+		if(ok) {
+		  if(wave_data!=NULL) {
+		    wave_data->setSegueStartPos(pos);
+		    wave_data->setSegueEndPos(pos+offset);
+		    wave_data->setMetadataFound(true);
+		  }
+		}
+	      }
+	    }
+	  }
+	  if(label=="C") {  // AV Category
+	    userdef+=("av_category="+arg+", ");
+	  }
+	  if(label=="CI") {  // AV Artist/Client
+	    if(wave_data!=NULL) {
+	      wave_data->setArtist(arg);
+	    }
+	  }
+	  if(label=="CL") {  // AV Class
+	    userdef+=("av_class="+arg+", ");
+	  }
+	  if(label=="CO") {  // AV Codes
+	    userdef+=("av_codes="+arg+", ");
+	  }
+	  if(label=="D") {   // AV Description
+	    if(wave_data!=NULL) {
+	      wave_data->setTitle(arg);
+	      wave_data->setMetadataFound(true);
+	    }
+	  }
+	  if(label=="G") {   // AV ???
+	  }
+	  if(label=="IN") {  // AV Intro
+	    if(ok) {
+	      if(wave_data!=NULL) {
+		wave_data->setIntroStartPos(wave_data->startPos());
+		wave_data->setIntroEndPos(1000*arg.toInt());
+		wave_data->setMetadataFound(true);
+	      }
+	    }
+	  }
+	  if(label=="K") {   // AV Kill Date
+	  }
+	  if(label=="N") {   // AV Name
+	  }
+	  if(label=="Q") {   // AV Outcue
+	    if(wave_data!=NULL) {
+	      wave_data->setOutCue(arg);
+	      wave_data->setMetadataFound(true);
+	    }
+	  }
+	  if(label=="S") {   // AV Start Date
+	  }
+	  if(label=="SR") {  // AV ???
+	  }
+	  // printf("Label: %s  Arg: %s\n",(const char *)label,(const char *)arg);
+	  label="";
+	  arg="";
+	  istate=0;
+	}
+	else {
+	  arg+=av10_chunk_data[i];
+	}
+	break;	
+    }
+    if(!userdef.isEmpty()) {
+      if(wave_data!=NULL) {
+	wave_data->setUserDefined(userdef.left(userdef.length()-2));
+      }      
+    }
+  }
+
+  return true;
+}
+
+
 bool RDWaveFile::GetList(int fd)
 {
   unsigned chunk_size=0;
@@ -2477,6 +2694,9 @@ bool RDWaveFile::GetList(int fd)
 */
   unsigned offset=4;
   while(ReadListElement(chunk_data,&offset,chunk_size));
+  if((wave_data->segueStartPos()>=0)&&(wave_data->segueEndPos()<0)) {
+    wave_data->setSegueEndPos(ext_time_length);
+  }
   delete chunk_data;
   return true;
 }
@@ -2526,11 +2746,13 @@ bool RDWaveFile::ReadListElement(unsigned char *buffer,unsigned *offset,
     wave_data->setMetadataFound(true);
   }
   if(!strcmp(tag,"tint")) {
-    wave_data->setIntroLength(RDSetTimeLength(((char *)buffer)+(*offset)));
+    wave_data->setIntroStartPos(0);
+    wave_data->setIntroEndPos(RDSetTimeLength(((char *)buffer)+(*offset)));
     wave_data->setMetadataFound(true);
   }
   if(!strcmp(tag,"ttim")) {
-    wave_data->setFullLength(RDSetTimeLength(((char *)buffer)+(*offset)));
+    wave_data->setStartPos(0);
+    wave_data->setEndPos(RDSetTimeLength(((char *)buffer)+(*offset)));
     wave_data->setMetadataFound(true);
   }
   if(!strcmp(tag,"tend")) {
@@ -2542,7 +2764,7 @@ bool RDWaveFile::ReadListElement(unsigned char *buffer,unsigned *offset,
     wave_data->setMetadataFound(true);
   }
   if(!strcmp(tag,"taux")) {
-    wave_data->setSegueLength(RDSetTimeLength(((char *)buffer)+(*offset)));
+    wave_data->setSegueStartPos(RDSetTimeLength(((char *)buffer)+(*offset)));
     wave_data->setMetadataFound(true);
   }
   if(!strcmp(tag,"tbpm")) {
@@ -2563,7 +2785,7 @@ bool RDWaveFile::ReadListElement(unsigned char *buffer,unsigned *offset,
   }
 
   *offset+=len;
-  while((buffer[*offset]==0)&&((*offset)<size)) {
+  while(((*offset)<size) && (buffer[*offset]==0)) {
     (*offset)++;
   }
   return true;
@@ -2625,11 +2847,12 @@ void RDWaveFile::ReadTmcTag(const QString tag,const QString value)
     wave_data->setMetadataFound(true);
   }
   if(tag=="INTRO") {
-    wave_data->setIntroLength(RDSetTimeLength(value.stripWhiteSpace()));
+    wave_data->setIntroStartPos(0);
+    wave_data->setIntroEndPos(RDSetTimeLength(value.stripWhiteSpace()));
     wave_data->setMetadataFound(true);
   }
   if(tag=="AUX") {
-    wave_data->setSegueLength(RDSetTimeLength(value.stripWhiteSpace()));
+    wave_data->setSegueStartPos(RDSetTimeLength(value.stripWhiteSpace()));
     wave_data->setMetadataFound(true);
   }
   if(tag=="END") {
@@ -2683,7 +2906,7 @@ void RDWaveFile::ReadId3Metadata()
     return;
   }
   ID3_Frame *frame=NULL;
-  ID3_Tag id3_tag(wave_file.name());
+  ID3_Tag id3_tag(QCString().sprintf("%s",(const char *)wave_file.name().utf8()));
   if((frame=id3_tag.Find(ID3FID_TITLE))!=NULL) {
     wave_data->setTitle(ID3_GetString(frame,ID3FN_TEXT));
     wave_data->setMetadataFound(true);
@@ -3298,7 +3521,7 @@ int RDWaveFile::GetAtxOffset(int fd)
 bool RDWaveFile::GetFlacStreamInfo()
 {
   FLAC__StreamMetadata sinfo;
-  if(!FLAC__metadata_get_streaminfo(wave_file.name(),&sinfo)) {
+  if(!FLAC__metadata_get_streaminfo(QCString().sprintf("%s",(const char *)wave_file.name().utf8()),&sinfo)) {
     return false;
   }
   samples_per_sec=sinfo.data.stream_info.sample_rate;
@@ -3596,6 +3819,9 @@ QDate RDWaveFile::cutDate(char *buffer,unsigned start_point)
   }
   date_buf[4]=0;
   sscanf(date_buf,"%d",&year);
+  if(year>RD_MAX_YEAR) {
+    year=RD_MAX_YEAR;
+  }
   for(i=0;i<2;i++) {
     date_buf[i]=buffer[start_point+i+5];
   }
@@ -3759,6 +3985,26 @@ void RDWaveFile::GrowAlloc(size_t size)
 }
 
 
+void RDWaveFile::ValidateMetadata()
+{
+  if(wave_data==NULL) {
+    return;
+  }
+  if(!wave_data->metadataFound()) {
+    return;
+  }
+  if(wave_data->startPos()<0) {
+    wave_data->setStartPos(0);
+  }
+  if(wave_data->endPos()<0) {
+    wave_data->setEndPos(ext_time_length);
+  }
+  if((wave_data->segueStartPos()>=0)&&(wave_data->segueEndPos()<0)) {
+    wave_data->setSegueEndPos(wave_data->endPos());
+  }
+}
+
+
 #ifdef HAVE_VORBIS
 int RDWaveFile::WriteOggPage(ogg_page *page)
 {
