@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_group.h,v 1.11 2007/02/14 21:51:02 fredg Exp $
+//      $Id: edit_group.h,v 1.13 2008-07-26 00:01:38 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -35,7 +35,7 @@
 #include <qlabel.h>
 #include <qpushbutton.h>
 
-#include <rlistselector.h>
+#include <rdlistselector.h>
 
 #include <rdgroup.h>
 
@@ -44,7 +44,7 @@ class EditGroup : public QDialog
 {
  Q_OBJECT
  public:
-  EditGroup(QString name,QWidget *parent=0,const char *name=0);
+  EditGroup(QString group,QWidget *parent=0,const char *name=0);
   ~EditGroup();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -66,7 +66,7 @@ class EditGroup : public QDialog
   QSpinBox *group_highcart_box;
   QLabel *group_enforcerange_label;
   QCheckBox *group_enforcerange_box;
-  RListSelector *group_svcs_sel;
+  RDListSelector *group_svcs_sel;
   QCheckBox *group_music_box;
   QCheckBox *group_traffic_box;
   QCheckBox *group_nownext_box;
