@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_rdlibrary.cpp,v 1.26 2007/02/14 21:51:02 fredg Exp $
+//      $Id: edit_rdlibrary.cpp,v 1.30 2007-12-29 21:05:35 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,8 +32,6 @@
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
 #include <qsqldatabase.h>
-#include <rconf.h>
-#include <math.h>
 
 #include <rd.h>
 #include <edit_rdlibrary.h>
@@ -163,7 +161,7 @@ EditRDLibrary::EditRDLibrary(RDStation *station,unsigned instance,
   //
   // Ripper Device
   //
-  lib_ripdev_edit=new QLineEdit(this,"lib_name_edit");
+  lib_ripdev_edit=new QLineEdit(this,"lib_ripper_device");
   lib_ripdev_edit->setGeometry(160,188,100,19);
   lib_ripdev_edit->setValidator(validator);
   QLabel *lib_ripdev_label=new QLabel(lib_ripdev_edit,tr("&Ripper Device:"),
@@ -174,7 +172,7 @@ EditRDLibrary::EditRDLibrary(RDStation *station,unsigned instance,
   //
   // Paranoia Level
   //
-  lib_paranoia_box=new QComboBox(this,"lib_name_edit");
+  lib_paranoia_box=new QComboBox(this,"lib_paranoia_box");
   lib_paranoia_box->setGeometry(160,210,100,19);
   QLabel *lib_paranoia_label=
     new QLabel(lib_paranoia_box,tr("&Paranoia Level:"),
@@ -202,7 +200,7 @@ EditRDLibrary::EditRDLibrary(RDStation *station,unsigned instance,
   //
   // FreeDB Server
   //
-  lib_cddb_edit=new QLineEdit(this,"lib_name_edit");
+  lib_cddb_edit=new QLineEdit(this,"lib_cddb_edit");
   lib_cddb_edit->setGeometry(160,256,160,19);
   lib_cddb_edit->setValidator(validator);
   QLabel *lib_cddb_label=new QLabel(lib_cddb_edit,tr("&FreeDB Server:"),this,
@@ -213,7 +211,7 @@ EditRDLibrary::EditRDLibrary(RDStation *station,unsigned instance,
   //
   // Format
   //
-  lib_format_box=new QComboBox(this,"lib_name_edit");
+  lib_format_box=new QComboBox(this,"lib_format_box");
   lib_format_box->setGeometry(160,280,150,19);
   connect(lib_format_box,SIGNAL(activated(int)),this,SLOT(formatData(int)));
   QLabel *lib_format_label=new QLabel(lib_format_box,tr("&Format:"),this,
@@ -224,7 +222,7 @@ EditRDLibrary::EditRDLibrary(RDStation *station,unsigned instance,
   //
   // Sample Rate
   //
-  lib_samprate_box=new QComboBox(this,"lib_name_edit");
+  lib_samprate_box=new QComboBox(this,"lib_samperate_box");
   lib_samprate_box->setGeometry(160,304,100,19);
   QLabel *lib_samprate_label=new QLabel(lib_samprate_box,tr("&Sample Rate:"),
 					this,"lib_samprate_label");
@@ -234,49 +232,61 @@ EditRDLibrary::EditRDLibrary(RDStation *station,unsigned instance,
   //
   // Bitrate
   //
-  lib_bitrate_box=new QComboBox(this,"lib_name_edit");
+  lib_bitrate_box=new QComboBox(this,"lib_bitrate_box");
   lib_bitrate_box->setGeometry(160,328,130,19);
   QLabel *lib_bitrate_label=new QLabel(lib_bitrate_box,tr("&Bitrate:"),this,
 				       "lib_bitrate_label");
   lib_bitrate_label->setGeometry(25,328,130,19);
   lib_bitrate_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
+  //
+  // Enable Editor
+  //
+  lib_editor_box=new QComboBox(this,"lib_editor_box");
+  lib_editor_box->setGeometry(160,352,60,19);
+  lib_editor_box->insertItem(tr("No"));
+  lib_editor_box->insertItem(tr("Yes"));
+  QLabel *lib_editor_label=new QLabel(lib_editor_box,tr("Allow E&xternal Editing:"),this,
+				       "lib_editor_label");
+  lib_editor_label->setGeometry(25,352,130,19);
+  lib_editor_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
   //
   // Defaults
   //
   QLabel *default_label=new QLabel(tr("Defaults"),this,"default_label");
-  default_label->setGeometry(25,365,120,19);
+  default_label->setGeometry(25,389,120,19);
   default_label->setFont(big_font);
   default_label->setAlignment(AlignRight|ShowPrefix);
 
   //
   // Default Channels
   //
-  lib_channels_box=new QComboBox(this,"lib_name_edit");
-  lib_channels_box->setGeometry(160,384,60,19);
+  lib_channels_box=new QComboBox(this,"lib_channels_box");
+  lib_channels_box->setGeometry(160,408,60,19);
   QLabel *lib_channels_label=new QLabel(lib_channels_box,tr("&Channels:"),this,
 				       "lib_channels_label");
-  lib_channels_label->setGeometry(25,384,130,19);
+  lib_channels_label->setGeometry(25,408,130,19);
   lib_channels_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
   // Default Record Mode
   //
-  lib_recmode_box=new QComboBox(this,"lib_name_edit");
-  lib_recmode_box->setGeometry(160,408,100,19);
+  lib_recmode_box=new QComboBox(this,"lib_recmode_box");
+  lib_recmode_box->setGeometry(160,432,100,19);
   QLabel *lib_recmode_label=new QLabel(lib_recmode_box,tr("Record Mode:"),this,
 				       "lib_recmode_label");
-  lib_recmode_label->setGeometry(25,408,130,19);
+  lib_recmode_label->setGeometry(25,432,130,19);
   lib_recmode_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
   // Default Trim State
   //
-  lib_trimstate_box=new QComboBox(this,"lib_name_edit");
-  lib_trimstate_box->setGeometry(160,430,100,19);
+  lib_trimstate_box=new QComboBox(this,"lib_trimstate_box");
+  lib_trimstate_box->setGeometry(160,454,100,19);
   QLabel *lib_trimstate_label=new QLabel(lib_trimstate_box,tr("AutoTrim:"),
 					 this,"lib_trimstate_label");
-  lib_trimstate_label->setGeometry(25,430,130,19);
+  lib_trimstate_label->setGeometry(25,454,130,19);
   lib_trimstate_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
@@ -302,6 +312,20 @@ EditRDLibrary::EditRDLibrary(RDStation *station,unsigned instance,
   //
   // Populate Fields
   //
+  if(station->scanned()) {
+    lib_input_card->setMaxCards(station->cards());
+    lib_output_card->setMaxCards(station->cards());
+    for(int i=0;i<lib_input_card->maxCards();i++) {
+      lib_input_card->setMaxPorts(i,station->cardInputs(i));
+      lib_output_card->setMaxPorts(i,station->cardOutputs(i));
+    }
+  }
+  else {
+    QMessageBox::information(this,tr("No Audio Configuration Data"),
+			    tr("Channel assignments will not be available for this host, as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on this host\n(by executing, as user 'root',  the command \"/etc/init.d/rivendell start\")\nin order to populate the audio resources database."));
+    lib_input_card->setDisabled(true);
+    lib_output_card->setDisabled(true);
+  }
   lib_input_card->setCard(lib_lib->inputCard());
   lib_input_card->setPort(lib_lib->inputPort());
   lib_output_card->setCard(lib_lib->outputCard());
@@ -359,21 +383,7 @@ EditRDLibrary::EditRDLibrary(RDStation *station,unsigned instance,
     lib_trimstate_box->setCurrentItem(1);
   }
   lib_cddb_edit->setText(lib_lib->cddbServer());
-
-  if(station->scanned()) {
-    lib_input_card->setMaxCards(station->cards());
-    lib_output_card->setMaxCards(station->cards());
-    for(int i=0;i<lib_input_card->maxCards();i++) {
-      lib_input_card->setMaxPorts(i,station->cardInputs(i));
-      lib_output_card->setMaxPorts(i,station->cardOutputs(i));
-    }
-  }
-  else {
-    QMessageBox::information(this,tr("No Audio Configuration Data"),
-			    tr("Channel assignments will not be available for this host, as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on this host\n(by executing, as user 'root',  the command \"/etc/init.d/rivendell start\")\nin order to populate the audio resources database."));
-    lib_input_card->setDisabled(true);
-    lib_output_card->setDisabled(true);
-  }
+  lib_editor_box->setCurrentItem(lib_lib->enableEditor());
 }
 
 
@@ -391,7 +401,7 @@ EditRDLibrary::~EditRDLibrary()
 
 QSize EditRDLibrary::sizeHint() const
 {
-  return QSize(375,534);
+  return QSize(375,558);
 } 
 
 
@@ -450,6 +460,7 @@ void EditRDLibrary::okData()
 	break;
   }
   lib_lib->setCddbServer(lib_cddb_edit->text());
+  lib_lib->setEnableEditor(lib_editor_box->currentItem());
   done(0);
 }
 
