@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_station.cpp,v 1.47 2008-08-18 20:26:15 fredg Exp $
+//      $Id: edit_station.cpp,v 1.48 2008-09-18 19:02:11 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -49,6 +49,7 @@
 #include <edit_backup.h>
 #include <view_adapters.h>
 #include <list_dropboxes.h>
+#include <list_encoders.h>
 #include <globals.h>
 
 EditStation::EditStation(QString display,QWidget *parent,const char *name)
@@ -368,11 +369,20 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   button->setText(tr("Audio\nResources"));
   connect(button,SIGNAL(clicked()),this,SLOT(viewAdaptersData()));
 
+  //
+  // Encoders Configuration Button
+  //
+  button=new QPushButton(this,"encoders_button");
+  button->setGeometry(280,357,80,50);
+  button->setFont(font);
+  button->setText(tr("Custom\nEncoders"));
+  connect(button,SIGNAL(clicked()),this,SLOT(editEncodersData()));
+
   //
   // Backups Configuration Button
   //
   button=new QPushButton(this,"backup_button");
-  button->setGeometry(280,357,80,50);
+  button->setGeometry(145,417,80,50);
   button->setFont(font);
   button->setText(tr("Backups"));
   connect(button,SIGNAL(clicked()),this,SLOT(editBackupsData()));
@@ -484,7 +494,7 @@ void EditStation::heartbeatClickedData()
 
 QSize EditStation::sizeHint() const
 {
-  return QSize(375,487);
+  return QSize(375,547);
 } 
 
 
@@ -665,6 +675,14 @@ void EditStation::editDropboxesData()
 }
 
 
+void EditStation::editEncodersData()
+{
+  ListEncoders *list_conf=new ListEncoders(station_station->name(),this);
+  list_conf->exec();
+  delete list_conf;
+}
+
+
 QString EditStation::DisplayPart(QString string)
 {
   for(unsigned i=0;i<string.length();i++) {
