@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_station.h,v 1.23 2007/06/12 20:26:34 fredg Exp $
+//      $Id: edit_station.h,v 1.28 2008-09-18 19:02:11 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,7 +32,6 @@
 #include <qlineedit.h>
 #include <qcombobox.h>
 #include <qspinbox.h>
-#include <rlistselector.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
 
@@ -69,6 +68,7 @@ class EditStation : public QDialog
    void editHostvarsData();
    void editBackupsData();
    void editDropboxesData();
+   void editEncodersData();
 
   private:
    QString DisplayPart(QString);
@@ -78,10 +78,13 @@ class EditStation : public QDialog
    QLineEdit *station_name_edit;
    QLineEdit *station_description_edit;
    QComboBox *station_default_name_edit;
+   QComboBox *station_broadcast_sec_edit;
    QLineEdit *station_address_edit;
+   QLineEdit *station_editor_cmd_edit;
    QSpinBox *station_timeoffset_box;
    QLineEdit *station_startup_cart_edit;
    QCheckBox *station_heartbeat_box;
+   QCheckBox *station_filter_box;
    QLabel *station_hbcart_label;
    QLineEdit *station_hbcart_edit;
    QPushButton *station_hbcart_button;
