@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_svc.cpp,v 1.38 2007/09/14 14:06:27 fredg Exp $
+//      $Id: edit_svc.cpp,v 1.40 2008-08-04 14:00:59 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,8 +31,8 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 
+#include <rddb.h>
 #include <rd.h>
 #include <rduser.h>
 #include <rdpasswd.h>
@@ -48,7 +48,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString group;
 
   //
@@ -325,7 +325,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent,const char *name)
   //
   svc_tfctitle_length_spin=new QSpinBox(this,"svc_tfctitle_length_spin");
   svc_tfctitle_length_spin->setGeometry(295,276,50,19);
-  svc_tfctitle_length_spin->setRange(0,32);
+  svc_tfctitle_length_spin->setRange(0,255);
   label=new QLabel(svc_tfctitle_length_spin,
 		   tr("Length:"),this,
 		   "svc_tfctitle_win_path_label");
@@ -808,7 +808,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent,const char *name)
   //
   svc_mustitle_length_spin=new QSpinBox(this,"svc_mustitle_length_spin");
   svc_mustitle_length_spin->setGeometry(730,297,50,19);
-  svc_mustitle_length_spin->setRange(0,32);
+  svc_mustitle_length_spin->setRange(0,255);
   label=new QLabel(svc_mustitle_length_spin,
 		   tr("Length:"),this,
 		   "svc_mustitle_win_path_label");
@@ -1175,7 +1175,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent,const char *name)
   //
   group=svc_svc->trackGroup();
   sql="select NAME from GROUPS order by NAME";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     svc_voice_group_box->insertItem(q->value(0).toString());
     if(q->value(0).toString()==group) {
