@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: test_import.cpp,v 1.19 2007/09/14 14:06:27 fredg Exp $
+//      $Id: test_import.cpp,v 1.20 2007-10-04 20:53:30 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,7 +27,7 @@
 
 #include <rddatedialog.h>
 #include <rdconf.h>
-
+#include <rddb.h>
 #include <test_import.h>
 #include <rduser.h>
 #include <rdpasswd.h>
@@ -206,7 +206,7 @@ void TestImport::importData()
                                  INSERT_BREAK,INSERT_TRACK,INSERT_FIRST,TITLE,\
                                  TRACK_STRING from `%s_TEST_IMP`",
 				(const char *)test_svc->name());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
 //    if(test_src==RDSvc::Music) {
       if(q->value(9).toUInt()==RDEventLine::InsertBreak) {
@@ -263,7 +263,7 @@ void TestImport::importData()
   // printf("IMPORT TABLE: %s_TEST_IMP\n",(const char *)test_svc->name());
   sql=QString().sprintf("drop table `%s_TEST_IMP`",
 			(const char *)test_svc->name());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
