@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: local_macros.cpp,v 1.22 2007/07/15 20:51:33 stgabriel Exp $
+//      $Id: local_macros.cpp,v 1.26 2008-04-02 16:47:25 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,6 +24,7 @@
 
 #include <rdmacro.h>
 #include <rdairplay.h>
+#include <rddb.h>
 
 #include <globals.h>
 #include <button_log.h>
@@ -31,10 +32,11 @@
 void MainWidget::RunLocalMacros(RDMacro *rml)
 {
   QString str;
+  QString logname;
   RDAirPlayConf::PanelType panel_type;
   int panel_number;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QPalette pal;
   bool ret=false;
   int fade;
@@ -108,15 +110,15 @@ void MainWidget::RunLocalMacros(RDMacro *rml)
 	  }
 	  return;
 	}
-	if(rml->argQuantity()==1) {   // Claer Log
+	if(rml->argQuantity()==1) {   // Clear Log
 	  air_log[rml->arg(0).toInt()-1]->clear();
 	}
 	else {  // Load Log
 	  sql=QString().
 	    sprintf("select NAME from LOGS where (NAME=\"%s\" && TYPE=0)",
 		    (const char *)rml->arg(1).toString());
-	  q=new QSqlQuery(sql);
-	  if(q->size()<1) {
+	  q=new RDSqlQuery(sql);
+	  if(!q->first()) {
 	    delete q;
 	    if(rml->echoRequested()) {
 	      rml->acknowledge(false);
@@ -124,17 +126,34 @@ void MainWidget::RunLocalMacros(RDMacro *rml)
 	    }
 	    return;
 	  }
+	  logname=q->value(0).toString();
 	  delete q;
 	  air_log[rml->arg(0).toInt()-1]->
-	    setLogName(QString().sprintf("%s_LOG",
-				       (const char *)rml->arg(1).toString()));
+	    setLogName(QString().sprintf("%s_LOG",(const char *)logname));
 	  air_log[rml->arg(0).toInt()-1]->load();
 	}
 	if(rml->argQuantity()==3) { // Start Log
-	  if((rml->arg(2).toInt()>=0)&&
-	     (rml->arg(2).toInt()<air_log[rml->arg(0).toInt()-1]->size())) {
-	    air_log[rml->arg(0).toInt()-1]->play(rml->arg(2).toInt(),
-						 RDLogLine::StartMacro);
+	  if(rml->arg(2).toInt()<air_log[rml->arg(0).toInt()-1]->size()) {
+	    if(rml->arg(2).toInt()>=0) {  // Unconditional start
+	      air_log[rml->arg(0).toInt()-1]->play(rml->arg(2).toInt(),
+						   RDLogLine::StartMacro);
+	    }
+	    if(rml->arg(2).toInt()==-2) {  // Start if trans type allows
+	      if(air_log[rml->arg(0).toInt()-1]->logLine(0)!=NULL) {
+		switch(air_log[rml->arg(0).toInt()-1]->logLine(0)->
+		       transType()) {
+		  case RDLogLine::Play:
+		  case RDLogLine::Segue:
+		    air_log[rml->arg(0).toInt()-1]->
+		      play(0,RDLogLine::StartMacro);
+		    break;
+		    
+		  case RDLogLine::Stop:
+		  case RDLogLine::NoTrans:
+		    break;
+		}
+	      }
+	    }
 	  }
 	}
 	if(rml->echoRequested()) {
