@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_upload.h,v 1.6 2007/02/14 21:53:27 fredg Exp $
+//      $Id: edit_upload.h,v 1.8 2007-12-31 18:49:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -43,8 +43,8 @@ class EditUpload : public QDialog
 {
  Q_OBJECT
  public:
-  EditUpload(int id,std::vector<int> *adds,QString *filter=0,
-	     QString *group=0,QWidget *parent=0,const char *name=0);
+ EditUpload(int id,std::vector<int> *adds,QString *filter,
+	     QWidget *parent=0,const char *name=0);
   ~EditUpload();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -74,6 +74,7 @@ class EditUpload : public QDialog
   QCheckBox *edit_active_button;
   QComboBox *edit_station_box;
   QTimeEdit *edit_starttime_edit;
+  QComboBox *edit_feed_box;
   QLineEdit *edit_description_edit;
   QLineEdit *edit_url_edit;
   QLabel *edit_username_label;
@@ -95,9 +96,8 @@ class EditUpload : public QDialog
   QCheckBox *edit_fri_button;
   QCheckBox *edit_sat_button;
   QCheckBox *edit_oneshot_box;
-  QString *edit_filter;
-  QString *edit_group;
   std::vector<int> *edit_added_events;
+  QString *edit_filter;
 };
 
 
