@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatch.cpp,v 1.115 2007/12/31 18:49:10 fredg Exp $
+//      $Id: rdcatch.cpp,v 1.120 2008-10-02 18:52:12 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -205,10 +205,11 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   QString err (tr("rdcatch : "));
   catch_db=RDInitDb (&err);
   if(!catch_db) {
-    log (err);
+    log(RDConfig::LogErr,err);
     exit(0);
   }
-  connect (RDDbStatus(),SIGNAL(logText(QString)),this,SLOT(log(QString)));
+  connect(RDDbStatus(),SIGNAL(logText(RDConfig::LogPriority,const QString &)),
+	  this,SLOT(log(RDConfig::LogPriority,const QString &)));
   //
   // Allocate Global Resources
   //
@@ -281,8 +282,9 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
     catch_connect[catch_station_count].station=
       q->value(0).toString().lower();
     connect(catch_connect[catch_station_count].connect,
-	    SIGNAL(statusChanged(int,unsigned,RDDeck::Status,int)),
-	    this,SLOT(statusChangedData(int,unsigned,RDDeck::Status,int)));
+      SIGNAL(statusChanged(int,unsigned,RDDeck::Status,int,const QString &)),
+      this,
+      SLOT(statusChangedData(int,unsigned,RDDeck::Status,int,const QString &)));
     connect(catch_connect[catch_station_count].connect,
 	    SIGNAL(monitorChanged(int,unsigned,bool)),
 	    this,SLOT(monitorChangedData(int,unsigned,bool)));
@@ -596,9 +598,9 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   timer->start(1,true);
 }
 
-void MainWidget::log(QString msg)
+void MainWidget::log(RDConfig::LogPriority prio,const QString &msg)
 {
-  fprintf (stderr,"%s\n",msg.ascii());
+  catch_config->log("RDCatch",prio,msg);
 }
 
 QSize MainWidget::sizeHint() const
@@ -950,18 +952,15 @@ void MainWidget::ripcUserData()
 
 
 void MainWidget::statusChangedData(int serial,unsigned chan,
-				   RDDeck::Status status,int id)
+				   RDDeck::Status status,int id,
+				   const QString &cutname)
 {
   // printf("statusChangedData(%d,%u,%d,%d)\n",serial,chan,status,id);
   int mon=GetMonitor(serial,chan);
   if(id>0) {
     RDListViewItem *item=GetItem(id);
-    if(item==NULL) {
-      fprintf(stderr,"rdcatch: received status update for nonexistent ID %d\n",
-	      id);
-      return;
-    }
-    switch(status) {
+    if(item!=NULL) {
+      switch(status) {
 	case RDDeck::Offline:
 	  item->setBackgroundColor(EVENT_ERROR_COLOR);
 	  break;
@@ -982,9 +981,17 @@ void MainWidget::statusChangedData(int serial,unsigned chan,
 	case RDDeck::Recording:
 	  item->setBackgroundColor(EVENT_ACTIVE_COLOR);
 	  break;
+      }
+      item->setText(32,QString().sprintf("%u",status));
+      UpdateExitCode(item);
+    }
+    else {
+      if(id<RDCATCHD_DYNAMIC_BASE_ID) {
+	fprintf(stderr,
+		"rdcatch: received status update for nonexistent ID %d\n",id);
+	return;
+      }
     }
-    item->setText(32,QString().sprintf("%u",status));
-    UpdateExitCode(item);
   }
   if(mon>=0) {
     int waiting_count=0;
@@ -1013,14 +1020,15 @@ void MainWidget::statusChangedData(int serial,unsigned chan,
       item=(RDListViewItem *)item->nextSibling();
     }
     if(waiting_count>1) {
-      catch_monitor[mon]->deckMon()->setStatus(status,-1);
+      catch_monitor[mon]->deckMon()->setStatus(status,-1,cutname);
     }
     else {
       if((active_count==0)||(status!=RDDeck::Idle)) {
-	catch_monitor[mon]->deckMon()->setStatus(status,id);
+	catch_monitor[mon]->deckMon()->setStatus(status,id,cutname);
       }
       else {
-	catch_monitor[mon]->deckMon()->setStatus(RDDeck::Waiting,waiting_id);
+	catch_monitor[mon]->deckMon()->
+	  setStatus(RDDeck::Waiting,waiting_id,cutname);
       }
     }
   }
@@ -1045,8 +1053,13 @@ void MainWidget::scrollButtonData()
 
 
 void MainWidget::reportsButtonData()
-{}
-
+{
+  ListReports *lr=new ListReports(catch_show_today_box->isChecked(),
+				  catch_show_active_box->isChecked(),
+				  catch_dow_box->currentItem(),this);
+  lr->exec();
+  delete lr;
+}
 
 
 void MainWidget::headButtonData()
@@ -1069,7 +1082,8 @@ void MainWidget::headButtonData()
     catch_cae->setPlayPortActive(catch_audition_card,catch_audition_port,catch_audition_stream);
     catch_cae->setOutputVolume(catch_audition_card,catch_audition_stream,catch_audition_port,
            0+cut->playGain());
-    catch_cae->play(catch_play_handle,RDCATCH_AUDITION_LENGTH,1000,false);
+    catch_cae->play(catch_play_handle,RDCATCH_AUDITION_LENGTH,
+		    RD_TIMESCALE_DIVISOR,false);
     head_playing=true;
     delete cut;
   }
@@ -1103,7 +1117,7 @@ void MainWidget::tailButtonData()
     catch_cae->setOutputVolume(catch_audition_card,catch_audition_stream,catch_audition_port,
            0+cut->playGain());
     catch_cae->play(catch_play_handle,RDCATCH_AUDITION_LENGTH,
-		    1000,false);
+		    RD_TIMESCALE_DIVISOR,false);
     tail_playing=true;
     delete cut;
   }
@@ -2578,15 +2592,20 @@ int main(int argc,char *argv[])
 	  ".");
   a.installTranslator(&qt);
 
-  QTranslator libradio(0);
-  libradio.load(QString(PREFIX)+QString("/share/srlabs/libradio_")+
-		QTextCodec::locale(),".");
-  a.installTranslator(&libradio);
-
-  QTranslator tests(0);
-  tests.load(QString(PREFIX)+QString("/share/srlabs/rdcatch_")+
+  QTranslator rd(0);
+  rd.load(QString(PREFIX)+QString("/share/rivendell/librd_")+
 	     QTextCodec::locale(),".");
-  a.installTranslator(&tests);
+  a.installTranslator(&rd);
+
+  QTranslator rdhpi(0);
+  rdhpi.load(QString(PREFIX)+QString("/share/rivendell/librdhpi_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&rdhpi);
+
+  QTranslator tr(0);
+  tr.load(QString(PREFIX)+QString("/share/rivendell/rdcatch_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&tr);
 
   //
   // Start Event Loop
