@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatch.h,v 1.45 2007/10/13 16:31:14 dmills Exp $
+//      $Id: rdcatch.h,v 1.47 2008-10-02 18:52:13 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -72,7 +72,7 @@ class MainWidget : public QWidget
   QSizePolicy sizePolicy() const;
   
  private slots:
-  void log(QString);
+  void log(RDConfig::LogPriority prio,const QString &msg);
   void resizeData();
   void connectedData(int serial,bool state);
   void nextEventData();
@@ -81,7 +81,8 @@ class MainWidget : public QWidget
   void deleteData();
   void ripcConnectedData(bool);
   void ripcUserData();
-  void statusChangedData(int,unsigned,RDDeck::Status,int);
+  void statusChangedData(int,unsigned,RDDeck::Status,int,
+			 const QString &cutname);
   void monitorChangedData(int serial,unsigned chan,bool state);
   void scrollButtonData();
   void reportsButtonData();
