@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatchd_socket.cpp,v 1.3 2007/02/14 21:55:07 fredg Exp $
+//      $Id: rdcatchd_socket.cpp,v 1.4 2007-09-14 14:06:52 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,8 +29,6 @@
 #include <stdio.h>
 #include <signal.h>
 #include <string.h>
-#include <math.h>
-#include <rconf.h>
 
 #include <rdcatchd_socket.h>
 
