@@ -2,9 +2,9 @@
 //
 // Edit a Rivendell Log
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_log.cpp,v 1.82 2007/12/31 18:49:10 fredg Exp $
+//      $Id: edit_log.cpp,v 1.87 2008-10-21 10:59:41 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -69,6 +69,7 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
 {
   QString sql;
   RDSqlQuery *q;
+  QStringList services_list;
 
   edit_logname=logname;
   edit_clipboard=clipboard;
@@ -105,6 +106,9 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   label_font.setPixelSize(12);
   QFont title_font=QFont("Helvetica",12,QFont::Normal);
   title_font.setPixelSize(12);
+  QFont length_font=QFont("Helvetica",10,QFont::Bold);
+  length_font.setPixelSize(10);
+
   
   //
   // Create Icons
@@ -220,7 +224,7 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   // Start Date
   //
   edit_startdate_edit=new QDateEdit(this,"edit_startdate_edit");
-  edit_startdate_label=new QLabel(edit_service_box,tr("Start Date:"),this,
+  edit_startdate_label=new QLabel(edit_startdate_edit,tr("Start Date:"),this,
 				  "edit_startdate_label");
   edit_startdate_label->setFont(label_font);
   edit_startdate_label->setAlignment(AlignRight|AlignVCenter);  
@@ -232,7 +236,7 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   // End Date
   //
   edit_enddate_edit=new QDateEdit(this,"edit_enddate_edit");
-  edit_enddate_label=new QLabel(edit_service_box,tr("End Date:"),
+  edit_enddate_label=new QLabel(edit_startdate_edit,tr("End Date:"),
 				this,"edit_enddate_label");
   edit_enddate_label->setFont(label_font);
   edit_enddate_label->setAlignment(AlignRight|AlignVCenter);  
@@ -261,6 +265,29 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   edit_enddate_box_label->setFont(label_font);
   edit_enddate_box_label->setAlignment(AlignLeft|AlignVCenter);  
 
+  //
+  // Time Counter Section
+  //
+  edit_time_label=new QLabel(tr("Run Length"),this);
+  edit_time_label->setFont(label_font);
+  edit_time_label->setAlignment(AlignCenter);  
+
+  //
+  // Stop Time Counter
+  //
+  edit_stoptime_edit=new QLineEdit(this,"edit_stoptime_edit");
+  edit_stoptime_label=new QLabel(edit_stoptime_edit,tr("Next Stop:"),this);
+  edit_stoptime_label->setFont(label_font);
+  edit_stoptime_label->setAlignment(AlignRight|AlignVCenter);  
+
+  //
+  // End Time Counter
+  //
+  edit_endtime_edit=new QLineEdit(this,"edit_endtime_edit");
+  edit_endtime_label=new QLabel(edit_endtime_edit,tr("Log End:"),this);
+  edit_endtime_label->setFont(label_font);
+  edit_endtime_label->setAlignment(AlignRight|AlignVCenter);  
+
   //
   // Log Event List
   //
@@ -291,8 +318,6 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   edit_log_list->setColumnAlignment(9,Qt::AlignLeft);
   edit_log_list->addColumn(tr("LABEL"));
   edit_log_list->setColumnAlignment(10,Qt::AlignHCenter);
-//  edit_log_list->addColumn(tr("POST PT"));
-//  edit_log_list->setColumnAlignment(11,Qt::AlignHCenter);
   edit_log_list->addColumn(tr("SOURCE"));
   edit_log_list->setColumnAlignment(11,Qt::AlignHCenter);
   edit_log_list->addColumn(tr("LINE ID"));
@@ -303,6 +328,8 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
 	  this,SLOT(doubleClickData(QListViewItem *)));
   connect(edit_log_list,SIGNAL(clicked(QListViewItem *)),
 	  this,SLOT(clickedData(QListViewItem *)));
+  connect(edit_log_list,SIGNAL(selectionChanged()),
+	  this,SLOT(selectionChangedData()));
 
   //
   //  Insert Cart Button
@@ -448,21 +475,35 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   // Populate Data
   //
   edit_description_edit->setText(edit_log->description());
-  sql=QString("select NAME from SERVICES");
-  q=new RDSqlQuery(sql);
-  int n=-1;
-  QString service=edit_log->service();
-  while(q->next()) {
-    edit_service_box->insertItem(q->value(0).toString());
-    if(q->value(0).toString()==service) {
-      n=q->at();
-      edit_service_edit->setText(q->value(0).toString());
+
+  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+    services_list = rduser->services();
+  } else { // RDStation::HostSec
+    sql=QString("select NAME from SERVICES");
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      services_list.append( q->value(0).toString() );
     }
+    delete q;
+  }
+
+  int n=-1;
+  int ncounter=0;
+  QString service=edit_log->service();
+  for ( QStringList::Iterator it = services_list.begin(); 
+        it != services_list.end(); ++it ) {
+    edit_service_box->insertItem(*it);
+    if(*it==service) {
+      n=ncounter;
+      edit_service_edit->setText(*it);
+    }
+    ncounter++;
   }
   if(n>=0) {
     edit_service_box->setCurrentItem(n);
   }
-  delete q;
+
+
   if(edit_log->autoRefresh()) {
     edit_autorefresh_box->setCurrentItem(0);
     edit_autorefresh_edit->setText(tr("Yes"));
@@ -630,6 +671,7 @@ void EditLog::insertCartButtonData()
   delete edit;
   RefreshList();
   SelectRecord(id);
+  UpdateSelection();
 }
 
 
@@ -706,6 +748,7 @@ void EditLog::insertMarkerButtonData()
   RefreshList();
   UpdateTracks();
   SelectRecord(id);
+  UpdateSelection();
 }
 
 
@@ -717,11 +760,19 @@ void EditLog::clickedData(QListViewItem *item)
     edit_player->setCart(0);
     return;
   }
-  edit_player->setCart(rditem->text(3).toUInt());
+  else {
+    edit_player->setCart(rditem->text(3).toUInt());
+  }
 #endif  // WIN32
 }
 
 
+void EditLog::selectionChangedData()
+{
+  UpdateSelection();
+}
+
+
 void EditLog::doubleClickData(QListViewItem *item)
 {
   editButtonData();
@@ -790,6 +841,7 @@ void EditLog::editButtonData()
   }
   RefreshList();
   SelectRecord(id);
+  UpdateSelection();
 }
 
 
@@ -843,6 +895,7 @@ void EditLog::deleteButtonData()
     RenumberList(line);
   }
   UpdateTracks();
+  UpdateSelection();
 }
 
 
@@ -860,6 +913,7 @@ void EditLog::upButtonData()
   edit_changed=true;
   RefreshList();
   SelectRecord(id);
+  UpdateSelection();
 }
 
 
@@ -877,6 +931,7 @@ void EditLog::downButtonData()
   edit_changed=true;
   RefreshList();
   SelectRecord(id);
+  UpdateSelection();
 }
 
 
@@ -885,6 +940,7 @@ void EditLog::cutButtonData()
   copyButtonData();
   deleteButtonData();
   UpdateTracks();
+  UpdateSelection();
 }
 
 
@@ -923,6 +979,7 @@ void EditLog::pasteButtonData()
   RefreshList();
   UpdateTracks();
   SelectRecord(id);
+  UpdateSelection();
 }
 
 
@@ -958,7 +1015,12 @@ void EditLog::saveasData()
   RDAddLog *log=NULL;
 
   if(rduser->createLog()) {
-    log=new RDAddLog(&logname,&svcname,NULL,tr("Add Log"),this,"add_log");
+    if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+      log=new RDAddLog(&logname,&svcname,NULL,tr("Add Log"),this,"add_log",
+                       rduser);
+    } else { // RDStation::HostSec
+      log=new RDAddLog(&logname,&svcname,NULL,tr("Add Log"),this,"add_log");
+    }
     if(log->exec()<0) {
       return;
     }
@@ -1091,14 +1153,21 @@ void EditLog::resizeEvent(QResizeEvent *e)
   edit_autorefresh_box->setGeometry(180,94,50,22);
   edit_autorefresh_edit->setGeometry(180,94,50,22);
   edit_autorefresh_label->setGeometry(10,94,165,22);
-  edit_startdate_edit->setGeometry(330,68,100,22);
-  edit_startdate_label->setGeometry(240,68,85,22);
-  edit_enddate_edit->setGeometry(520,68,100,22);
-  edit_enddate_label->setGeometry(440,68,75,22);
+  edit_startdate_edit->setGeometry(315,68,100,22);
+  edit_startdate_label->setGeometry(240,68,70,22);
+  edit_enddate_edit->setGeometry(490,68,100,22);
+  edit_enddate_label->setGeometry(415,68,70,22);
   edit_startdate_box->setGeometry(250,98,15,15);
-  edit_enddate_box->setGeometry(450,98,15,15);
+  edit_enddate_box->setGeometry(430,98,15,15);
   edit_startdate_box_label->setGeometry(270,96,175,20);
-  edit_enddate_box_label->setGeometry(470,96,175,20);
+  edit_enddate_box_label->setGeometry(450,96,140,20);
+
+  edit_time_label->setGeometry(655,62,75,20);
+  edit_stoptime_label->setGeometry(625,82,65,18);
+  edit_stoptime_edit->setGeometry(695,82,60,18);
+  edit_endtime_label->setGeometry(625,102,65,18);
+  edit_endtime_edit->setGeometry(695,102,60,18);
+
   edit_log_list->setGeometry(10,128,
 			    size().width()-20,size().height()-258);
   edit_cart_button->setGeometry(20,size().height()-125,80,50);
@@ -1132,6 +1201,15 @@ void EditLog::paintEvent(QPaintEvent *e)
   p->fillRect(60,8,size().width()-120,24,QColor(lightGray));
   p->fillRect(9,size().height()-130,size().width()-20,60,
 	      QColor(lightGray));
+
+  p->setPen(black);
+  p->setBrush(black);
+  p->moveTo(624,70);
+  p->lineTo(760,70);
+  p->lineTo(760,124);
+  p->lineTo(624,124);
+  p->lineTo(624,70);
+
   p->end();
   delete p;
 }
@@ -1207,16 +1285,6 @@ void EditLog::RefreshLine(RDListViewItem *item)
 	}
 	break;
 
-      case RDLogLine::Overlap:
-	item->setText(2,tr("OVERLAP"));
-	if(logline->hasCustomTransition()) {
-	  item->setTextColor(2,RD_CUSTOM_TRANSITION_COLOR,QFont::Bold);
-	}
-	else {
-	  item->setTextColor(2,item->textColor(1),QFont::Normal);
-	}
-	break;
-
       default:
 	break;
   }
@@ -1369,6 +1437,51 @@ void EditLog::RefreshList()
 }
 
 
+void EditLog::UpdateSelection()
+{
+  RDListViewItem *rditem=SingleSelection();
+  if(rditem==NULL) {  // Multiple items selected?
+    edit_endtime_edit->setText("");
+    edit_stoptime_label->setText(tr("Selected:"));
+    QListViewItem *next=edit_log_list->firstChild();
+    int start_line=-1;
+    int end_line=-1;
+    while(next!=NULL) {
+      if(edit_log_list->isSelected(next)) {
+	if((start_line<0)&&(next->text(12).toInt()!=END_MARKER_ID)) {
+	  start_line=next->text(13).toInt();
+	}
+	if(next->text(12).toInt()!=END_MARKER_ID) {
+	  end_line=next->text(13).toInt();
+	}
+      }
+      next=next->nextSibling();
+    }
+    if(start_line>=0) {
+      edit_stoptime_edit->setText(RDGetTimeLength(edit_log_event->
+		      length(start_line,end_line+1),true,false));
+    }
+    return;
+  }
+  if(rditem->text(12).toInt()>0) {
+    edit_endtime_edit->setText(RDGetTimeLength(edit_log_event->
+      length(rditem->text(13).toInt(),edit_log_event->size()),true,false));
+    edit_stoptime_label->setText(tr("Next Stop:"));
+    int stoplen=edit_log_event->lengthToStop(rditem->text(13).toInt());
+    if(stoplen>=0) {
+      edit_stoptime_edit->setText(RDGetTimeLength(stoplen,true,false));
+    }
+    else {
+      edit_stoptime_edit->setText("");
+    }
+  }
+  else {
+    edit_endtime_edit->setText("");
+    edit_stoptime_edit->setText("");
+  }
+}
+
+
 bool EditLog::UpdateColor(RDListViewItem *item,RDLogLine *logline)
 {
   bool ret=true;
