@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_log.h,v 1.32 2007/09/14 14:06:56 fredg Exp $
+//      $Id: edit_log.h,v 1.33 2008-10-08 18:43:30 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -69,6 +69,7 @@ class EditLog : public QDialog
   void insertCartButtonData();
   void insertMarkerButtonData();
   void clickedData(QListViewItem *item);
+  void selectionChangedData();
   void doubleClickData(QListViewItem *item);
   void editButtonData();
   void deleteButtonData();
@@ -92,6 +93,7 @@ class EditLog : public QDialog
   void SaveLog();
   void RefreshLine(RDListViewItem *item);
   void RefreshList();
+  void UpdateSelection();
   void RenumberList(int line);
   bool UpdateColor(RDListViewItem *item,RDLogLine *logline);
   void SelectRecord(int id);
@@ -163,6 +165,11 @@ class EditLog : public QDialog
   unsigned edit_start_macro;
   unsigned edit_end_macro;
   RDSimplePlayer *edit_player;
+  QLabel *edit_time_label;
+  QLabel *edit_stoptime_label;
+  QLineEdit *edit_stoptime_edit;
+  QLabel *edit_endtime_label;
+  QLineEdit *edit_endtime_edit;
 };
 
 
