@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: bt16x2.h,v 1.5 2007/09/14 14:06:59 fredg Exp $
+//      $Id: bt16x2.h,v 1.6 2008-09-30 18:19:42 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,6 +29,7 @@
 #include <rdmatrix.h>
 #include <rdmacro.h>
 #include <rdtty.h>
+#include <rdoneshot.h>
 
 #define BT16X2_UNIT_ID 0
 #define BT16X2_POLL_INTERVAL 100
@@ -48,9 +49,16 @@ class Bt16x2 : public QObject
  signals:
   void rmlEcho(RDMacro *cmd);
   void gpiChanged(int matrix,int line,bool state);
+  void gpoChanged(int matrix,int line,bool state);
+
+ private slots:
+  void gpiOneshotData(void *data);
+  void gpoOneshotData(void *data);
 
  private:
   RDTTYDevice *bt_device;
+  RDOneShot *bt_gpi_oneshot;
+  RDOneShot *bt_gpo_oneshot;
   int bt_matrix;
   int bt_inputs;
   int bt_outputs;
@@ -58,6 +66,7 @@ class Bt16x2 : public QObject
   int bt_gpos;
   int bt_istate;
   bool bt_gpi_state[BT16X2_GPIO_PINS];
+  bool bt_gpi_mask[BT16X2_GPIO_PINS];
 };
 
 
