@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: local_macros.cpp,v 1.45 2007/11/09 18:51:19 fredg Exp $
+//      $Id: local_macros.cpp,v 1.49 2008-09-30 18:19:44 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,8 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <stdlib.h>
+
 #include <rd.h>
 #include <rdmatrix.h>
 #include <rdtty.h>
@@ -30,12 +32,14 @@
 
 void MainObject::gpiChangedData(int matrix,int line,bool state)
 {
-  // LogLine(QString().sprintf("gpiChangedData(%d,%d,%d)",matrix,line,state));
+  // LogLine(RDConfig::LogWarning,QString().sprintf("gpiChangedData(%d,%d,%d)",matrix,line,state));
+
+  ripcd_gpi_state[matrix][line]=state;
+  BroadcastCommand(QString().sprintf("GI %d %d %d %d!",matrix,line,state,
+				     ripcd_gpi_mask[matrix][line]));
   if(!ripcd_gpi_mask[matrix][line]) {
     return;
   }
-  ripcd_gpi_state[matrix][line]=state;
-  BroadcastCommand(QString().sprintf("GI %d %d %d!",matrix,line,state));
   if(state==ripcd_gpi_polarity[matrix][line]) {
     return;
   }
@@ -46,13 +50,42 @@ void MainObject::gpiChangedData(int matrix,int line,bool state)
 }
 
 
+void MainObject::gpoChangedData(int matrix,int line,bool state)
+{
+  // LogLine(RDConfig::LogWarning,QString().sprintf("gpoChangedData(%d,%d,%d)",matrix,line,state));
+
+  ripcd_gpo_state[matrix][line]=state;
+  BroadcastCommand(QString().sprintf("GO %d %d %d %d!",matrix,line,state,
+				     ripcd_gpo_mask[matrix][line]));
+  if(!ripcd_gpo_mask[matrix][line]) {
+    return;
+  }
+  if(state==ripcd_gpo_polarity[matrix][line]) {
+    return;
+  }
+  if(ripcd_gpo_macro[matrix][line]<=0) {
+    return;
+  }
+  ExecCart(ripcd_gpo_macro[matrix][line]);
+}
+
+
 void MainObject::gpiStateData(int matrix,unsigned line,bool state)
 {
-  // LogLine(QString().sprintf("gpiStateData(%d,%d,%d)",matrix,line,state));
+  // LogLine(RDConfig::LogWarning,QString().sprintf("gpiStateData(%d,%d,%d)",matrix,line,state));
+
   BroadcastCommand(QString().sprintf("GI %d %u %d!",matrix,line,state));
 }
 
 
+void MainObject::gpoStateData(int matrix,unsigned line,bool state)
+{
+  LogLine(RDConfig::LogWarning,QString().sprintf("gpoStateData(%d,%d,%d)",matrix,line,state));
+
+  BroadcastCommand(QString().sprintf("GO %d %u %d!",matrix,line,state));
+}
+
+
 void MainObject::ttyTrapData(int cartnum)
 {
   ExecCart(cartnum);
@@ -98,6 +131,7 @@ void MainObject::LoadLocalMacros()
     ripcd_matrix_type[i]=RDMatrix::None;
     ripcd_sas32000[i]=NULL;
     ripcd_gpis[i]=0;
+    ripcd_gpos[i]=0;
     ripcd_switcher_tty[i][0]=-1;
     ripcd_switcher_tty[i][1]=-1;
   }
@@ -117,6 +151,7 @@ void MainObject::LoadLocalMacros()
     ripcd_matrix_type[q->value(0).toInt()]=(RDMatrix::Type)q->value(1).toInt();
     matrix=new RDMatrix(rdstation->name(),q->value(0).toInt());
     ripcd_gpis[q->value(0).toInt()]=matrix->gpis();
+    ripcd_gpos[q->value(0).toInt()]=matrix->gpos();
     switch(ripcd_matrix_type[q->value(0).toInt(0)]) {
 	case RDMatrix::LocalGpio:
 	  ripcd_gpio[q->value(0).toInt()]=new LocalGpio(matrix,this);
@@ -126,6 +161,9 @@ void MainObject::LoadLocalMacros()
 	  connect(ripcd_gpio[q->value(0).toInt()],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_gpio[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 
 	case RDMatrix::Sas32000:
@@ -182,6 +220,9 @@ void MainObject::LoadLocalMacros()
 	  connect(ripcd_sas64000gpi[q->value(0).toInt()],
 		  SIGNAL(rmlEcho(RDMacro *)),
 		  this,SLOT(sendRml(RDMacro *)));
+	  connect(ripcd_sas64000gpi[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 
 	case RDMatrix::BtSs82:
@@ -196,6 +237,9 @@ void MainObject::LoadLocalMacros()
 	  connect(ripcd_btss82[q->value(0).toInt()],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btss82[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 
 	case RDMatrix::Bt16x1:
@@ -232,6 +276,9 @@ void MainObject::LoadLocalMacros()
 	  connect(ripcd_btacs82[q->value(0).toInt()],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btacs82[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 
 	case RDMatrix::SasUsi:
@@ -245,6 +292,9 @@ void MainObject::LoadLocalMacros()
 	  connect(ripcd_sasusi[q->value(0).toInt()],
 		  SIGNAL(rmlEcho(RDMacro *)),
 		  this,SLOT(sendRml(RDMacro *)));
+	  connect(ripcd_sasusi[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 
 	case RDMatrix::Bt16x2:
@@ -259,6 +309,9 @@ void MainObject::LoadLocalMacros()
 	  connect(ripcd_bt16x2[q->value(0).toInt()],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_bt16x2[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 
 	case RDMatrix::BtSs124:
@@ -300,6 +353,9 @@ void MainObject::LoadLocalMacros()
 	  connect(ripcd_vguest[q->value(0).toInt()],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_vguest[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 
 	case RDMatrix::BtSs164:
@@ -314,6 +370,9 @@ void MainObject::LoadLocalMacros()
 	  connect(ripcd_btss164[q->value(0).toInt()],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btss164[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 
 	case RDMatrix::StarGuideIII:
@@ -339,6 +398,9 @@ void MainObject::LoadLocalMacros()
 	  connect(ripcd_btss42[q->value(0).toInt()],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btss42[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 
 	case RDMatrix::LiveWire:
@@ -349,9 +411,28 @@ void MainObject::LoadLocalMacros()
 	  connect(ripcd_livewire[q->value(0).toInt()],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_livewire[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  connect(ripcd_livewire[q->value(0).toInt()],
 		  SIGNAL(gpiState(int,unsigned,bool)),
 		  this,SLOT(gpiStateData(int,unsigned,bool)));
+	  connect(ripcd_livewire[q->value(0).toInt()],
+		  SIGNAL(gpoState(int,unsigned,bool)),
+		  this,SLOT(gpoStateData(int,unsigned,bool)));
+	  break;
+
+	case RDMatrix::Quartz1:
+	  ripcd_quartz1[q->value(0).toInt()]=new Quartz1(matrix,this);
+	  if(matrix->portType(RDMatrix::Primary)==RDMatrix::TtyPort) {
+	    ripcd_switcher_tty[matrix->matrix()][0]=
+	      matrix->port(RDMatrix::Primary);
+	    ripcd_switcher_tty[matrix->matrix()][1]=-1;
+	    ripcd_tty_inuse[matrix->port(RDMatrix::Primary)]=true;
+	  }
+	  connect(ripcd_quartz1[q->value(0).toInt()],
+		  SIGNAL(rmlEcho(RDMacro *)),
+		  this,SLOT(sendRml(RDMacro *)));
 	  break;
 
 	default:
@@ -414,11 +495,14 @@ void MainObject::RunLocalMacros(RDMacro *rml)
   char logstr[RD_RML_MAX_LENGTH];
   char bin_buf[RD_RML_MAX_LENGTH];
   int d;
+  RDMatrix::GpioType gpio_type;
 
   rml->generateString(logstr,RD_RML_MAX_LENGTH-1);
-  LogLine(QString().sprintf("received rml: \'%s\' from %s",
+  LogLine(RDConfig::LogInfo,QString().sprintf("received rml: \'%s\' from %s",
 	  (const char *)logstr,(const char *)rml->address().toString()));
 
+  ForwardConvert(rml);
+
   switch(rml->command()) {
     case RDMacro::BO:
       tty_port=rml->arg(0).toInt();
@@ -468,28 +552,66 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       break;
       
     case RDMacro::GI:
-      matrix_num=rml->arg(0).toInt();
-      gpi=rml->arg(1).toInt()-1;
-      if((ripcd_matrix_type[matrix_num]==RDMatrix::None)||
-	 (gpi>(MAX_GPIO_PINS-1))||
-	 (gpi<0)||
-	 (rml->arg(2).toInt()<0)||(rml->arg(2).toInt()>1)||
-	 (rml->arg(3).toInt()<-1)||(rml->arg(3).toInt()>999999)) {
+      if(rml->argQuantity()!=5) {
 	if(rml->echoRequested()) {
 	  rml->acknowledge(false);
 	  sendRml(rml);
 	}
 	return;
       }
-      ripcd_gpi_macro[matrix_num][gpi]=rml->arg(3).toInt();
-      if(rml->arg(2).toInt()==1) {
-	ripcd_gpi_polarity[matrix_num][gpi]=false;
+      matrix_num=rml->arg(0).toInt();
+      if(rml->arg(1).toString().lower()=="i") {
+	gpio_type=RDMatrix::GpioInput;
       }
       else {
-	ripcd_gpi_polarity[matrix_num][gpi]=true;
+	if(rml->arg(1).toString().lower()=="o") {
+	  gpio_type=RDMatrix::GpioOutput;
+	}
+	else {
+	  if(rml->echoRequested()) {
+	    rml->acknowledge(false);
+	    sendRml(rml);
+	  }
+	  return;
+	}
+      }
+      gpi=rml->arg(2).toInt()-1;
+      if((ripcd_matrix_type[matrix_num]==RDMatrix::None)||
+	 (gpi>(MAX_GPIO_PINS-1))||
+	 (gpi<0)||
+	 (rml->arg(3).toInt()<0)||(rml->arg(3).toInt()>1)||
+	 (rml->arg(4).toInt()<-1)||(rml->arg(4).toInt()>999999)) {
+	if(rml->echoRequested()) {
+	  rml->acknowledge(false);
+	  sendRml(rml);
+	}
+	return;
+      }
+      switch(gpio_type) {
+	case RDMatrix::GpioInput:
+	  ripcd_gpi_macro[matrix_num][gpi]=rml->arg(4).toInt();
+	  if(rml->arg(2).toInt()==1) {
+	    ripcd_gpi_polarity[matrix_num][gpi]=false;
+	  }
+	  else {
+	    ripcd_gpi_polarity[matrix_num][gpi]=true;
+	  }
+	  BroadcastCommand(QString().sprintf("GC %d %d %d!",matrix_num,gpi,
+					     ripcd_gpi_macro[matrix_num][gpi]));
+	  break;
+
+	case RDMatrix::GpioOutput:
+	  ripcd_gpo_macro[matrix_num][gpi]=rml->arg(4).toInt();
+	  if(rml->arg(2).toInt()==1) {
+	    ripcd_gpo_polarity[matrix_num][gpi]=false;
+	  }
+	  else {
+	    ripcd_gpo_polarity[matrix_num][gpi]=true;
+	  }
+	  BroadcastCommand(QString().sprintf("GD %d %d %d!",matrix_num,gpi,
+					     ripcd_gpo_macro[matrix_num][gpi]));
+	  break;
       }
-      BroadcastCommand(QString().sprintf("GC %d %d %d!",matrix_num,gpi,
-					 ripcd_gpi_macro[matrix_num][gpi]));
       if(rml->echoRequested()) {
 	rml->acknowledge(true);
 	sendRml(rml);
@@ -497,25 +619,62 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       break;
       
     case RDMacro::GE:
-      matrix_num=rml->arg(0).toInt();
-      gpi=rml->arg(1).toInt()-1;
-      if((ripcd_matrix_type[matrix_num]==RDMatrix::None)||
-	 (gpi>(MAX_GPIO_PINS-1))||
-	 (gpi<0)||
-	 (rml->arg(2).toInt()<0)||(rml->arg(2).toInt()>1)) {
+      if(rml->argQuantity()!=4) {
 	if(rml->echoRequested()) {
 	  rml->acknowledge(false);
 	  sendRml(rml);
 	}
 	return;
       }
-      if(rml->arg(2).toInt()==1) {
-	ripcd_gpi_mask[matrix_num][gpi]=true;
-	BroadcastCommand(QString().sprintf("GM %d %d 1!",matrix_num,gpi));
+      matrix_num=rml->arg(0).toInt();
+      if(rml->arg(1).toString().lower()=="i") {
+	gpio_type=RDMatrix::GpioInput;
       }
       else {
-	ripcd_gpi_mask[matrix_num][gpi]=false;
-	BroadcastCommand(QString().sprintf("GM %d %d 0!",matrix_num,gpi));
+	if(rml->arg(1).toString().lower()=="o") {
+	  gpio_type=RDMatrix::GpioOutput;
+	}
+	else {
+	  if(rml->echoRequested()) {
+	    rml->acknowledge(false);
+	    sendRml(rml);
+	  }
+	  return;
+	}
+      }
+      gpi=rml->arg(2).toInt()-1;
+      if((ripcd_matrix_type[matrix_num]==RDMatrix::None)||
+	 (gpi>(MAX_GPIO_PINS-1))||
+	 (gpi<0)||
+	 (rml->arg(3).toInt()<0)||(rml->arg(3).toInt()>1)) {
+	if(rml->echoRequested()) {
+	  rml->acknowledge(false);
+	  sendRml(rml);
+	}
+	return;
+      }
+      switch(gpio_type) {
+	case RDMatrix::GpioInput:
+	  if(rml->arg(3).toInt()==1) {
+	    ripcd_gpi_mask[matrix_num][gpi]=true;
+	    BroadcastCommand(QString().sprintf("GM %d %d 1!",matrix_num,gpi));
+	  }
+	  else {
+	    ripcd_gpi_mask[matrix_num][gpi]=false;
+	    BroadcastCommand(QString().sprintf("GM %d %d 0!",matrix_num,gpi));
+	  }
+	  break;
+
+	case RDMatrix::GpioOutput:
+	  if(rml->arg(3).toInt()==1) {
+	    ripcd_gpo_mask[matrix_num][gpi]=true;
+	    BroadcastCommand(QString().sprintf("GN %d %d 1!",matrix_num,gpi));
+	  }
+	  else {
+	    ripcd_gpo_mask[matrix_num][gpi]=false;
+	    BroadcastCommand(QString().sprintf("GN %d %d 0!",matrix_num,gpi));
+	  }
+	  break;
       }
       if(rml->echoRequested()) {
 	rml->acknowledge(true);
@@ -613,7 +772,8 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	}
 	if(getuid()==0) {
 	  if(setgid(ripcd_config->gid())<0) {
-	    LogLine(QString().sprintf("unable to set group id %d for RN",
+	    LogLine(RDConfig::LogWarning,QString().
+		    sprintf("unable to set group id %d for RN",
 				      ripcd_config->gid()));
 	    if(rml->echoRequested()) {
 	      rml->acknowledge(false);
@@ -621,7 +781,8 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	    }
 	  }
 	  if(setuid(ripcd_config->uid())<0) {
-	    LogLine(QString().sprintf("unable to set user id %d for RN",
+	    LogLine(RDConfig::LogWarning,QString().
+		    sprintf("unable to set user id %d for RN",
 				      ripcd_config->uid()));
 	    if(rml->echoRequested()) {
 	      rml->acknowledge(false);
@@ -850,6 +1011,10 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  ripcd_livewire[rml->arg(0).toInt()]->processCommand(rml);
 	  break;
 	  
+	case RDMatrix::Quartz1:
+	  ripcd_quartz1[rml->arg(0).toInt()]->processCommand(rml);
+	  break;
+	  
 	default:
 	  if(rml->echoRequested()) {
 	    rml->acknowledge(false);
@@ -1046,6 +1211,12 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  ripcd_matrix_type[matrix_num]=RDMatrix::None;
 	  break;
 	  
+	case RDMatrix::Quartz1:
+	  delete ripcd_quartz1[matrix_num];
+	  ripcd_quartz1[matrix_num]=NULL;
+	  ripcd_matrix_type[matrix_num]=RDMatrix::None;
+	  break;
+	  
 	default:
 	  break;
       }
@@ -1055,6 +1226,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       //
       matrix=new RDMatrix(rdstation->name(),matrix_num);
       ripcd_gpis[matrix_num]=matrix->gpis();
+      ripcd_gpos[matrix_num]=matrix->gpos();
       tty_port=matrix->port(RDMatrix::Primary);
       if((tty_port=matrix->port(RDMatrix::Primary))>-1) {
 	ripcd_tty_inuse[tty_port]=true;
@@ -1074,6 +1246,8 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 		  this,SLOT(sendRml(RDMacro *)));
 	  connect(ripcd_gpio[matrix_num],SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_gpio[matrix_num],SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 	case RDMatrix::Sas32000:
 	  ripcd_sas32000[matrix_num]=new Sas32000(matrix,this);
@@ -1128,6 +1302,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  ripcd_tty_inuse[matrix->port(RDMatrix::Primary)]=true;
 	  connect(ripcd_sas64000gpi[matrix_num],SIGNAL(rmlEcho(RDMacro *)),
 		  this,SLOT(sendRml(RDMacro *)));
+	  connect(ripcd_sas64000gpi[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 	  
 	case RDMatrix::BtSs82:
@@ -1142,6 +1319,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  connect(ripcd_btss82[matrix_num],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btss82[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 	  
 	case RDMatrix::Bt16x1:
@@ -1178,6 +1358,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  connect(ripcd_btacs82[matrix_num],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btacs82[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 	  
 	case RDMatrix::SasUsi:
@@ -1191,6 +1374,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  ripcd_switcher_tty[matrix_num][1]=-1;
 	  connect(ripcd_sasusi[matrix_num],SIGNAL(rmlEcho(RDMacro *)),
 		  this,SLOT(sendRml(RDMacro *)));
+	  connect(ripcd_sasusi[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 	  
 	case RDMatrix::Bt16x2:
@@ -1205,6 +1391,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  connect(ripcd_bt16x2[matrix_num],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_bt16x2[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 	  
 	case RDMatrix::BtSs124:
@@ -1246,6 +1435,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  connect(ripcd_vguest[matrix_num],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_vguest[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 	  
 	case RDMatrix::BtSs164:
@@ -1260,6 +1452,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  connect(ripcd_btss164[matrix_num],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btss164[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 	  
 	case RDMatrix::StarGuideIII:
@@ -1285,6 +1480,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  connect(ripcd_btss42[matrix_num],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btss42[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 	  
 	case RDMatrix::LiveWire:
@@ -1295,6 +1493,28 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  connect(ripcd_livewire[matrix_num],
 		  SIGNAL(gpiChanged(int,int,bool)),
 		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_livewire[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
+	  connect(ripcd_livewire[matrix_num],
+		  SIGNAL(gpiState(int,unsigned,bool)),
+		  this,SLOT(gpiStateData(int,unsigned,bool)));
+	  connect(ripcd_livewire[matrix_num],
+		  SIGNAL(gpoState(int,unsigned,bool)),
+		  this,SLOT(gpoStateData(int,unsigned,bool)));
+	  break;
+	  
+	case RDMatrix::Quartz1:
+	  ripcd_quartz1[matrix_num]=new Quartz1(matrix);
+	  ripcd_matrix_type[matrix_num]=RDMatrix::Quartz1;
+	  if(matrix->portType(RDMatrix::Primary)==RDMatrix::TtyPort) {
+	    ripcd_switcher_tty[matrix_num][0]=
+	      matrix->port(RDMatrix::Primary);
+	    ripcd_tty_inuse[matrix->port(RDMatrix::Primary)]=true;
+	  }
+	  ripcd_switcher_tty[matrix_num][1]=-1;
+	  connect(ripcd_quartz1[matrix_num],SIGNAL(rmlEcho(RDMacro *)),
+		  this,SLOT(sendRml(RDMacro *)));
 	  break;
 	  
 	default:
@@ -1314,11 +1534,11 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       }
       if((rml->arg(0).toInt()==0)&&ripc_onair_flag) {
 	BroadcastCommand("TA 0!");
-	LogLine("onair flag OFF");
+	LogLine(RDConfig::LogInfo,"onair flag OFF");
       }
       if((rml->arg(0).toInt()==1)&&(!ripc_onair_flag)) {
 	BroadcastCommand("TA 1!");
-	LogLine("onair flag ON");
+	LogLine(RDConfig::LogInfo,"onair flag ON");
       }
       ripc_onair_flag=rml->arg(0).toInt();
       if(rml->echoRequested()) {
@@ -1353,7 +1573,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	str+=(rml->arg(i).toString()+" ");
       }
       str+=rml->arg(rml->argQuantity()-1).toString();
-      LogLine(QString().sprintf("Sending \"%s\" to %s:%d",(const char *)str,(const char *)addr.toString(),rml->arg(1).toInt()));
+      LogLine(RDConfig::LogDebug,QString().
+	      sprintf("Sending \"%s\" to %s:%d",(const char *)str,
+		      (const char *)addr.toString(),rml->arg(1).toInt()));
       ripcd_rml_send->writeBlock((const char *)str,str.length(),addr,
 				 (Q_UINT16)(rml->arg(1).toInt()));
       if(rml->echoRequested()) {
@@ -1363,8 +1585,50 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       break;
 
       default:
-//	LogLine(QString().sprintf("unhandled rml: \'%s\' from %s",
+//	LogLine(RDConfig::LogDebug,QString().sprintf("unhandled rml: \'%s\' from %s",
 //	       (const char *)logstr,(const char *)rml->address().toString()));
 	break;
   }
 }
+
+
+void MainObject::ForwardConvert(RDMacro *rml) const
+{
+  //
+  // Convert old RML syntax to current forms
+  //
+  switch(rml->command()) {
+    case RDMacro::GE:
+      if(rml->argQuantity()==3) {
+	rml->setArgQuantity(4);
+	for(int i=2;i>=1;i--) {
+	  rml->setArg(i+1,rml->arg(i));
+	}
+	rml->setArg(1,"I");
+      }
+      break;
+
+    case RDMacro::GI:
+      if(rml->argQuantity()==4) {
+	rml->setArgQuantity(5);
+	for(int i=3;i>=1;i--) {
+	  rml->setArg(i+1,rml->arg(i));
+	}
+	rml->setArg(1,"I");
+      }
+      break;
+
+    case RDMacro::GO:
+      if(rml->argQuantity()==4) {
+	rml->setArgQuantity(5);
+	for(int i=3;i>=1;i--) {
+	  rml->setArg(i+1,rml->arg(i));
+	}
+	rml->setArg(1,"O");
+      }
+      break;
+
+    default:
+      break;
+  }
+}
