@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: ripcd.h,v 1.44 2007/11/09 18:51:19 fredg Exp $
+//      $Id: ripcd.h,v 1.47 2008-09-30 18:19:45 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -59,6 +59,7 @@
 #include <starguide3.h>
 #include <btss42.h>
 #include <livewire.h>
+#include <quartz1.h>
 
 //
 // Global RIPCD Definitions
@@ -80,11 +81,13 @@ class MainObject : public QObject
   void newConnection(int fd);
 
  private slots:
-  void log (QString);
+  void log(RDConfig::LogPriority prio,const QString &msg);
   void sendRml(RDMacro *rml);
   void readRml();
   void gpiChangedData(int matrix,int line,bool state);
+  void gpoChangedData(int matrix,int line,bool state);
   void gpiStateData(int matrix,unsigned line,bool state);
+  void gpoStateData(int matrix,unsigned line,bool state);
   void ttyTrapData(int cartnum);
   void ttyScanData();
   void databaseBackup();
@@ -108,10 +111,14 @@ class MainObject : public QObject
   void RunLocalMacros(RDMacro *rml);
   void LoadGpiTable();
   void SendGpi(int ch,int matrix);
+  void SendGpo(int ch,int matrix);
   void SendGpiMask(int ch,int matrix);
+  void SendGpoMask(int ch,int matrix);
   void SendGpiCart(int ch,int matrix);
+  void SendGpoCart(int ch,int matrix);
   void RunMaintRoutine();
   int GetMaintInterval() const;
+  void ForwardConvert(RDMacro *rml) const;
   QSqlDatabase *ripcd_db;
   QString ripcd_host;
   bool debug;
@@ -128,7 +135,6 @@ class MainObject : public QObject
   QSocketDevice *ripcd_rml_reply;
   QHostAddress ripcd_host_addr;
   RDMatrix::Type ripcd_matrix_type[MAX_MATRICES];
-  bool ripcd_gpi_state[MAX_MATRICES][MAX_GPIO_PINS];
   LocalGpio *ripcd_gpio[MAX_MATRICES];
   Sas32000 *ripcd_sas32000[MAX_MATRICES];
   Sas64000 *ripcd_sas64000[MAX_MATRICES];
@@ -148,10 +154,17 @@ class MainObject : public QObject
   StarGuide3 *ripcd_starguide3[MAX_MATRICES];
   BtSs42 *ripcd_btss42[MAX_MATRICES];
   LiveWire *ripcd_livewire[MAX_MATRICES];
+  Quartz1 *ripcd_quartz1[MAX_MATRICES];
+  bool ripcd_gpi_state[MAX_MATRICES][MAX_GPIO_PINS];
+  bool ripcd_gpo_state[MAX_MATRICES][MAX_GPIO_PINS];
   int ripcd_gpi_macro[MAX_MATRICES][MAX_GPIO_PINS];
+  int ripcd_gpo_macro[MAX_MATRICES][MAX_GPIO_PINS];
   bool ripcd_gpi_mask[MAX_MATRICES][MAX_GPIO_PINS];
+  bool ripcd_gpo_mask[MAX_MATRICES][MAX_GPIO_PINS];
   bool ripcd_gpi_polarity[MAX_MATRICES][MAX_GPIO_PINS];
+  bool ripcd_gpo_polarity[MAX_MATRICES][MAX_GPIO_PINS];
   int ripcd_gpis[MAX_MATRICES];
+  int ripcd_gpos[MAX_MATRICES];
   bool ripcd_tty_inuse[MAX_TTYS];
   int ripcd_switcher_tty[MAX_MATRICES][2];
   RDTTYDevice *ripcd_tty_dev[MAX_TTYS];
