@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport.cpp,v 1.22 2008-08-05 16:20:45 fredg Exp $
+//      $Id: rdimport.cpp,v 1.23 2008-10-10 12:32:23 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -562,6 +562,7 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
 	  exit(0);
 	}
 	if(!import_temp_fix_filename.isEmpty()) {
+//	  printf("Fixed Name: %s\n",(const char *)import_temp_fix_filename);
 	  QFile::remove(import_temp_fix_filename);
 	  import_temp_fix_filename="";
 	}
@@ -1040,13 +1041,15 @@ bool MainObject::FixChunkSizes(const QString &filename)
       name[1]=name[2];
       name[2]=name[3];
       if(read(fd,name+3,1)<1) {
+	::close(fd);
 	return false;
       }
       off_t pos=lseek(fd,0,SEEK_CUR);
       char buf[4];
       lseek(fd,last_offset,SEEK_SET);
       read(fd,buf,4);
-      int size=buf[0]+(256*buf[1])+(65536*buf[2])+(16777216*buf[3])+1;
+      unsigned size=(0xff&buf[0])+(0xff&(256*buf[1]))+
+	(0xff&(65536*buf[2]))+(0xff&(16777216*buf[3]))+1;
       buf[0]=size&0xff;
       buf[1]=(size>>8)&0xff;
       buf[2]=(size>>16)&0xff;
@@ -1060,6 +1063,7 @@ bool MainObject::FixChunkSizes(const QString &filename)
     chunk_size=
       buffer[0]+(256*buffer[1])+(65536*buffer[2])+(16777216*buffer[3]);
   }
+  ::close(fd);
   return true;
 }
 
